// gloss texture
// (code is based on lighting4.{vert,frag}

// Don't forget to set light 0 to positional light

uniform sampler2D tex;

// we use a uniform 'shininess' here, instead of gl_FrontMaterial.shininess
// so that we can play with it (GLSLEditor doesn't offer to play with materials)
uniform float shininess;			// try 5 .. 30

varying vec3 normal;
varying vec3 lightVec;
varying vec3 viewVec;

varying vec4 ambient;


void main()
{
    vec4 color = ambient;

    vec3 n = normalize( normal );
    vec3 l = normalize( lightVec );
    vec3 v = normalize( viewVec );

    float NdotL = max( dot(n,l), 0.0 );

    if ( NdotL > 0.0 )
    {
        color += NdotL * gl_FrontMaterial.diffuse * gl_LightSource[0].diffuse;

	   vec3 h = normalize( l + v );
        float NdotH = max( dot(n,h), 0.0 );

        // now we use the texture to determine the shininess
        if ( NdotH > 0.0 )
        {
            float s = texture2D(tex, gl_TexCoord[0].xy).r ;
            color += gl_FrontMaterial.specular * gl_LightSource[0].specular * 
                     s * pow(NdotH, shininess);

            //float s = length( texture2D(tex, gl_TexCoord[0].xy).rg ) * 3.0;
            //s = min( s, 1.0 );
            //color += gl_FrontMaterial.specular * gl_LightSource[0].specular * 
            //         pow( s*NdotH, shininess );

            // orig. computation
            // color += gl_FrontMaterial.specular * gl_LightSource[0].specular * 
            //          pow(NdotH, shininess);
        }
    }

    gl_FragColor = color;
}
